@@ -27,6 +27,6 @@ def instrument_middlewares():
 
 
     except Exception as exc:
-        agentlogger('django middleware instrumentation error', exc)
+        agentlogger('django middleware instrumentation error'+ exc)
 
 
