@@ -1,4 +1,5 @@
 
+from apminsight import constants
 from apminsight.util import is_ext_comp, is_non_empty_string
 
 class Component:
@@ -9,9 +10,10 @@ class Component:
         self.ext = is_ext_comp(tracker.get_component())
         self.count = 0
         self.errcount = 0
-        self.host = tracker.get_info().get('host', '')
-        self.port = tracker.get_info().get('port', '-1')
-        if tracker.is_error():
+        self.http_err = 0
+        self.host = tracker.get_info().get(constants.host_str, '')
+        self.port = tracker.get_info().get(constants.port_str, '-1') or '-1'
+        if tracker.is_error() or tracker.is_http_err():
             self.errcount+=1
         else:
             self.count+=1
@@ -88,8 +90,8 @@ class Component:
         
         port_number = int(self.port)
         if is_non_empty_string(self.host) and port_number>0:
-            info['host'] = self.host
-            info['port'] = self.port
+            info[constants.host_str] = self.host
+            info[constants.port_str] = self.port
 
         return info
 
