@@ -13,7 +13,7 @@ class DbMetric:
 
 
     def accumulate(self, dbtracker):
-        info = dbtracker.extract_operartion_info()
+        info = dbtracker.get_info()
         if 'opn' not in info or 'obj' not in info:
             return
             
