@@ -41,13 +41,14 @@ class ErrorInfo():
             tb = self.exc.__traceback__
             while tb is not None:
                 file_name = tb.tb_frame.f_code.co_filename
-                func_name = tb.tb_frame.f_code.co_name
-                line_no = tb.tb_lineno
-                frames.append(['', file_name, func_name, line_no])
+                if not 'apminsight' in file_name:
+                    func_name = tb.tb_frame.f_code.co_name
+                    line_no = tb.tb_lineno
+                    frames.append(['', file_name, func_name, line_no])
                 tb = tb.tb_next
 
             self.stackframes = frames
-            return frames
+            return frames[-25:]
             
         except Exception:
             agentlogger.exception('unable to get exc stackframes')
