@@ -1,9 +1,9 @@
 
 from apminsight.agentfactory import get_agent
 from apminsight.logger import agentlogger
-from apminsight.metric.apdexmetric import TxnMetric
+from apminsight.metric.apdexmetric import WebTxnMetric, BgTxnMetric
 from apminsight.metric.dbmetric import DbMetric
-from apminsight.constants import webtxn_prefix
+from apminsight.constants import webtxn_prefix, webtxn_type, bgtxn_prefix
 from apminsight.util import is_empty_string
 
 class Metricstore:
@@ -17,6 +17,12 @@ class Metricstore:
         self.app_metric_sum = {}
         self.app_metric_avg = {}
 
+    def add_txn(self, txn):
+        if txn.get_txn_type()==webtxn_type:
+            self.add_web_txn(txn)
+        else:
+            self.add_bg_txn(txn)
+            
     def add_web_txn(self, txn):
         try:
             if(txn.is_completed() is not True):
@@ -25,9 +31,9 @@ class Metricstore:
             occurence = 0    
             namespace = webtxn_prefix + txn.get_url()
             match = namespace in self.web_txn_metric  
-        
+            txn.aggregate_trackers(txn.get_root_tracker())
             if match is not True:
-                metric = TxnMetric()
+                metric = WebTxnMetric()
                 metric.aggregate(txn)
                 self.web_txn_metric[namespace] = metric
                 self.check_and_include_in_trace(txn)
@@ -53,10 +59,40 @@ class Metricstore:
             agentlogger.exception('unable to add web txn')
         return False
 
+    def add_bg_txn(self, txn):
+        try:
+            if(txn.is_completed() is not True):
+                return False
 
+            occurence = 0    
+            namespace = bgtxn_prefix + txn.get_url()
+            match = namespace in self.bg_txn_metric  
+        
+            if match is not True:
+                metric = BgTxnMetric()
+                metric.aggregate(txn)
+                self.bg_txn_metric[namespace] = metric
+                self.check_and_include_in_trace(txn)
+                return True
+
+            matched_txn = self.bg_txn_metric.get(namespace)
+            
+            metric_limit = get_agent().get_threshold().get_bg_metric_size()
+            if len(self.bg_txn_metric) <= metric_limit:
+                matched_txn = self.bg_txn_metric.get(namespace)
+                matched_txn.aggregate(txn)
+                self.bg_txn_metric[namespace] = matched_txn
+
+            self.check_and_include_in_trace(txn)
+            return True
+
+        except Exception:
+            agentlogger.exception('unable to add web txn')
+        return False
+    
     def is_critical(self, txn):
         # external call count need to be considered
-        txn_info = txn.get_url() + '-' + txn.get_method()
+        txn_info = txn.get_url() + '-' + txn.get_http_request_method() if txn.get_txn_type==webtxn_type else txn.get_url()
         last_critically_collected = self.trace_history.get(txn_info, None)
         critical = False
         if last_critically_collected is None:
@@ -81,16 +117,27 @@ class Metricstore:
 
     def check_and_include_in_trace(self, txn):
         threshold = get_agent().get_threshold()
-        if threshold.is_trace_enabled() is not True:
-            return False
+        
+        if txn.get_txn_type()==webtxn_type:
+            if threshold.is_trace_enabled() is not True:
+                return False
+        else:
+            if threshold.is_bgtxn_trace_enabled() is not True:
+                return False
             
         if len(self.trace_list) > threshold.get_trace_metric_size():
             return False
 
         trace_reason = 0x0000
 
-        if txn.get_rt() >= threshold.get_trace_threshold():
+        if txn.get_txn_type()==webtxn_type:
+            
+            if txn.get_rt() >= threshold.get_trace_threshold():
+                trace_reason |= 0x0008
+                
+        elif txn.get_rt() >= threshold.get_bgtxn_trace_threshold():
             trace_reason |= 0x0008
+                
 
         if txn.get_exceptions_count() > 0:
             trace_reason |= 0x0010
@@ -106,13 +153,34 @@ class Metricstore:
         formatted_data = []
         ins_dbmetric = {}
         opn_dbmetric = {}
-        instance_metric = TxnMetric()
+        web_instance_metric = WebTxnMetric()
+        bg_instance_metric = BgTxnMetric()
 
         for txn_namespace in self.web_txn_metric.keys():
             txnmetric = self.web_txn_metric[txn_namespace]
             txn_data = txnmetric.get_formatted_data(ns=txn_namespace)
             formatted_data.append(txn_data)
-            instance_metric.accumulate(txnmetric)
+            web_instance_metric.accumulate(txnmetric)
+
+            txn_dbmetric = {}
+            for dbtracker in txnmetric.get_db_calls():
+                info = dbtracker.get_info()
+                opn = info.get('opn', '')
+                obj = info.get('obj', '')
+                if is_empty_string(opn) or is_empty_string(obj):
+                    continue
+
+                dbtracker.accumulate('db/'+opn+'/'+obj+'/dummy-db', txn_dbmetric)
+                dbtracker.accumulate('db/'+opn+'/all/dummy-db', opn_dbmetric)
+                dbtracker.accumulate('db/all/all/dummy-db', ins_dbmetric)
+
+            Metricstore.iter_and_append_dbmetric(formatted_data, txn_dbmetric, ns=txn_namespace)
+
+        for txn_namespace in self.bg_txn_metric.keys():
+            txnmetric = self.bg_txn_metric[txn_namespace]
+            txn_data = txnmetric.get_formatted_data(ns=txn_namespace)
+            formatted_data.append(txn_data)
+            bg_instance_metric.accumulate(txnmetric)
 
             txn_dbmetric = {}
             for dbtracker in txnmetric.get_dbcalls():
@@ -127,11 +195,14 @@ class Metricstore:
                 dbtracker.accumulate('db/all/all/dummy-db', ins_dbmetric)
 
             Metricstore.iter_and_append_dbmetric(formatted_data, txn_dbmetric, ns=txn_namespace)
-
-        if len(self.web_txn_metric) > 0:
+            
+        if len(self.web_txn_metric) > 0 or len(self.bg_txn_metric) > 0:
             Metricstore.iter_and_append_dbmetric(formatted_data, opn_dbmetric)
             Metricstore.iter_and_append_dbmetric(formatted_data, ins_dbmetric)
-            formatted_data.append(instance_metric.get_formatted_data())
+        if len(self.web_txn_metric) > 0:
+            formatted_data.append(web_instance_metric.get_formatted_data())
+        if len(self.bg_txn_metric) > 0:
+            formatted_data.append(web_instance_metric.get_formatted_data())
 
         return formatted_data
 
